@@ -1,7 +1,7 @@
 /*****************************************************************************
  * vlcplugin_mac.h: a VLC plugin for Mozilla (Mac interface)
  *****************************************************************************
- * Copyright (C) 2011-2013 VLC authors and VideoLAN
+ * Copyright (C) 2011-2015 VLC authors and VideoLAN
  * $Id$
  *
  * Authors: Felix Paul Kühne <fkuehne # videolan # org>
@@ -28,6 +28,8 @@
 
 #include "vlcplugin_base.h"
 
+//@class VLCPerInstanceStorage;
+
 class VlcPluginMac : public VlcPluginBase
 {
 public:
@@ -54,7 +56,11 @@ public:
     float m_media_width;
     float m_media_height;
 
+    void *_perInstanceStorage;
+    bool runningWithinFirefox;
+
 private:
+
     void set_player_window();
 };
 
